configlet create


Quando aggiungi un nuovo approccio, un nuovo articolo o un nuovo esercizio, dovrai creare file con nomi molto specifici. Richiedono anche di aggiungere o aggiornare dei file di configurazione. Con il comando create, configlet può fare tutto questo al posto tuo.

Utilizzo

Il comando create può essere usato per creare i file necessari ad aggiungere un nuovo approccio, articolo o esercizio, oltre a modificare eventuali file di configurazione.

configlet [global-options] create [command-options]

Options for create:
      --approach <slug>           The slug of the approach
      --article <slug>            The slug of the article
      --practice-exercise <slug>  The slug of the practice exercise
      --concept-exercise <slug>   The slug of the concept exercise
  -e, --exercise <slug>           Only operate on this exercise
  -o, --offline                   Do not update the cached 'problem-specifications' data

Creare un esercizio di pratica

La documentazione su come aggiungere un esercizio di pratica contiene istruzioni dettagliate.

Creare un esercizio di concetto

Per creare un esercizio di concetto, devi specificarne lo slug:

configlet create --concept-exercise bird-watcher

Questo creerà i file richiesti dall'esercizio di concetto, come specificato nella documentazione sugli esercizi di concetto.

Naturalmente, questo è solo il primo passo per creare un esercizio. Dopodiché dovrai:

  • Aggiungere i test al file dei test
  • Aggiungere un'implementazione di esempio
  • Definire il contenuto del file stub
  • Scrivere l'introduzione in .docs/introduction.md
  • Scrivere le istruzioni in .docs/instructions.md
  • Nel file .meta/config.json dell'esercizio:
    • Aggiungere il nome utente GitHub degli autori dell'esercizio alla chiave authors
  • Nel file config.json della traccia:
    • Controllare/aggiornare la difficoltà dell'esercizio
    • Aggiungere i concetti alla chiave concepts
    • Aggiungere i concetti alla chiave prerequisites

Creare un approccio

Per creare i file di un approccio, devi specificare lo slug dell'approccio e del suo esercizio:

configlet create --approach recursion --exercise collatz-conjecture

Questo creerà i file richiesti dall'approccio, come specificato nella documentazione sugli approcci.

Creare un articolo

Per creare i file di un articolo, devi specificare lo slug dell'articolo e del suo esercizio:

configlet create --article performance --exercise collatz-conjecture

Questo creerà i file richiesti dall'articolo, come specificato nella documentazione sugli articoli.